aboutsummaryrefslogtreecommitdiffstats
path: root/host/include/uhd/usrp
diff options
context:
space:
mode:
Diffstat (limited to 'host/include/uhd/usrp')
-rw-r--r--host/include/uhd/usrp/CMakeLists.txt4
-rw-r--r--host/include/uhd/usrp/dboard_id.hpp2
-rw-r--r--host/include/uhd/usrp/dboard_interface.hpp6
-rw-r--r--host/include/uhd/usrp/dboard_manager.hpp4
-rw-r--r--host/include/uhd/usrp/usrp2.hpp5
-rw-r--r--host/include/uhd/usrp/usrp_e.hpp (renamed from host/include/uhd/usrp/usrp1e.hpp)23
6 files changed, 19 insertions, 25 deletions
diff --git a/host/include/uhd/usrp/CMakeLists.txt b/host/include/uhd/usrp/CMakeLists.txt
index 4e0a92365..b9be370bd 100644
--- a/host/include/uhd/usrp/CMakeLists.txt
+++ b/host/include/uhd/usrp/CMakeLists.txt
@@ -21,7 +21,7 @@ INSTALL(FILES
dboard_id.hpp
dboard_interface.hpp
dboard_manager.hpp
- usrp1e.hpp
+ usrp_e.hpp
usrp2.hpp
- DESTINATION ${HEADER_DIR}/uhd/usrp
+ DESTINATION ${INCLUDE_DIR}/uhd/usrp
)
diff --git a/host/include/uhd/usrp/dboard_id.hpp b/host/include/uhd/usrp/dboard_id.hpp
index 4b2392bee..afacaf8ff 100644
--- a/host/include/uhd/usrp/dboard_id.hpp
+++ b/host/include/uhd/usrp/dboard_id.hpp
@@ -26,8 +26,6 @@ namespace uhd{ namespace usrp{
typedef boost::uint16_t dboard_id_t;
-static const dboard_id_t ID_NONE = 0xffff; //TODO: REMOVE ME
-
namespace dboard_id{
static const dboard_id_t NONE = 0xffff;
UHD_API std::string to_string(const dboard_id_t &id);
diff --git a/host/include/uhd/usrp/dboard_interface.hpp b/host/include/uhd/usrp/dboard_interface.hpp
index 5b40616f0..c779431ab 100644
--- a/host/include/uhd/usrp/dboard_interface.hpp
+++ b/host/include/uhd/usrp/dboard_interface.hpp
@@ -104,18 +104,16 @@ public:
*
* \param bank GPIO_TX_BANK or GPIO_RX_BANK
* \param value 16-bits, 0=FPGA input, 1=FPGA output
- * \param mask 16-bits, 0=ignore, 1=set
*/
- virtual void set_gpio_ddr(gpio_bank_t bank, boost::uint16_t value, boost::uint16_t mask) = 0;
+ virtual void set_gpio_ddr(gpio_bank_t bank, boost::uint16_t value) = 0;
/*!
* Set daughterboard GPIO pin values.
*
* \param bank GPIO_TX_BANK or GPIO_RX_BANK
* \param value 16 bits, 0=low, 1=high
- * \param mask 16 bits, 0=ignore, 1=set
*/
- virtual void write_gpio(gpio_bank_t bank, boost::uint16_t value, boost::uint16_t mask) = 0;
+ virtual void write_gpio(gpio_bank_t bank, boost::uint16_t value) = 0;
/*!
* Read daughterboard GPIO pin values
diff --git a/host/include/uhd/usrp/dboard_manager.hpp b/host/include/uhd/usrp/dboard_manager.hpp
index 6a105d1de..c7c091220 100644
--- a/host/include/uhd/usrp/dboard_manager.hpp
+++ b/host/include/uhd/usrp/dboard_manager.hpp
@@ -42,7 +42,7 @@ public:
/*!
* Register a dboard into the system.
- *
+ * For single subdevice boards, omit subdev_names.
* \param dboard_id the dboard id (rx or tx)
* \param dboard_ctor the dboard constructor function pointer
* \param name the canonical name for the dboard represented
@@ -52,7 +52,7 @@ public:
dboard_id_t dboard_id,
dboard_ctor_t dboard_ctor,
const std::string &name,
- const prop_names_t &subdev_names
+ const prop_names_t &subdev_names = prop_names_t(1, "")
);
/*!
diff --git a/host/include/uhd/usrp/usrp2.hpp b/host/include/uhd/usrp/usrp2.hpp
index 277ddc131..613b40ae3 100644
--- a/host/include/uhd/usrp/usrp2.hpp
+++ b/host/include/uhd/usrp/usrp2.hpp
@@ -29,17 +29,16 @@ namespace uhd{ namespace usrp{
class UHD_API usrp2 : public device{
public:
/*!
* Discover usrp2 devices over the ethernet.
*
* Recommended key/value pairs for the device hint address:
* hint["addr"] = address, where address is a resolvable address
* or ip address, which may or may not be a broadcast address.
*
- * This static method will be called by the device::discover.
* \param hint a device addr with the usrp2 address filled in
* \return a vector of device addresses for all usrp2s found
*/
- static device_addrs_t discover(const device_addr_t &hint);
+ static device_addrs_t find(const device_addr_t &hint);
/*!
* Make a usrp2 from a device address.
@@ -29,17 +29,16 @@ namespace uhd{ namespace usrp{
public:
/*!
- * Discover usrp2 devices over the ethernet.
+ * Find usrp2 devices over the ethernet.
*
* Recommended key/value pairs for the device hint address:
diff --git a/host/include/uhd/usrp/usrp1e.hpp b/host/include/uhd/usrp/usrp_e.hpp
index f4cc39d8e..557058261 100644
--- a/host/include/uhd/usrp/usrp1e.hpp
+++ b/host/include/uhd/usrp/usrp_e.hpp
@@ -15,8 +15,8 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#ifndef INCLUDED_UHD_USRP_USRP1E_HPP
-#define INCLUDED_UHD_USRP_USRP1E_HPP
+#ifndef INCLUDED_UHD_USRP_USRP_E_HPP
+#define INCLUDED_UHD_USRP_USRP_E_HPP
#include <uhd/config.hpp>
#include <uhd/device.hpp>
@@ -24,22 +24,21 @@
namespace uhd{ namespace usrp{
/*!
- * The usrp1e device class.
+ * The USRP-Embedded device class.
*/
-class UHD_API usrp1e : public device{
+class UHD_API usrp_e : public device{
public:
/*!
* Discover usrp1e devices on the system via the device node.
* This static method will be called by the device::discover.
* \param hint a device addr with the usrp1e address filled in
* \return a vector of device addresses for all usrp1es found
*/
- static device_addrs_t discover(const device_addr_t &hint);
+ static device_addrs_t find(const device_addr_t &hint);
/*!
* Make a usrp1e from a device address.
* \param addr the device address
* \return a device sptr to a new usrp1e
*/
static device::sptr make(const device_addr_t &addr);
@@ -52,4 +51,4 @@ public:
}} //namespace
-#endif /* INCLUDED_UHD_USRP_USRP1E_HPP */
+#endif /* INCLUDED_UHD_USRP_USRP_E_HPP */
@@ -24,22 +24,21 @@
public:
/*!
- * Discover usrp1e devices on the system via the device node.
- * This static method will be called by the device::discover.
- * \param hint a device addr with the usrp1e address filled in
- * \return a vector of device addresses for all usrp1es found
+ * Find usrp_e devices on the system via the device node.
+ * \param hint a device addr with the usrp_e address filled in
+ * \return a vector of device addresses for all usrp-e's found
*/
@@ -24,22 +24,21 @@
/*!
- * Make a usrp1e from a device address.
+ * Make a usrp_e from a device address.
* \param addr the device address
@@ -24,22 +24,21 @@
* \param addr the device address
- * \return a device sptr to a new usrp1e
+ * \return a device sptr to a new usrp_e
*/
static device::sptr make(const device_addr_t &addr);